﻿using System;
using System.Configuration;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WebEdition;
using PdfSharp;
using PdfSharp.Pdf;

using System.Diagnostics;
using GoogleMapLayerTest;
using System.Collections.ObjectModel;

namespace CSSamples.Samples.Overlays
{
    public partial class ShapeFilesOverGoogleMap : System.Web.UI.Page
    {
        protected void Page_Load(object sender, EventArgs e)
        {
            if (!Page.IsPostBack)
            {
                Map1.MapBackground.BackgroundBrush = new GeoSolidBrush(GeoColor.FromHtml("#B3C6D4"));
                Map1.CurrentExtent = new RectangleShape(-13939426.6371, 6701997.4056, -7812401.86, 2626987.386962);
                Map1.MapUnit = GeographyUnit.Meter;

                Map1.MapTools.OverlaySwitcher.Enabled = true;
                Map1.MapTools.MouseCoordinate.Enabled = true;

                GoogleOverlay google = new GoogleOverlay("Google Map");
                google.JavaScriptLibraryUri = new Uri(ConfigurationManager.AppSettings["GoogleUri"]);
                google.GoogleMapType = GoogleMapType.Normal;


                GoogleMapsLayer googleLayer = new GoogleMapsLayer("c:\\cache\\", "GoogleMapLayer", "ABQIAAAA1KPQi4YfHGdBrxrD7xfk3BShg55qzDjUncDQtZWMkgWc-6jGwhTE2_EhbB-MTW6vtSxa--SpoABjPA");

                ShapeFileFeatureLayer shapeFileFeatureLayer = new ShapeFileFeatureLayer(MapPath("~/SampleData/USA/STATES.shp"));
                shapeFileFeatureLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.FromArgb(100, 212, 220, 184), GeoColor.FromArgb(255, 132, 132, 154), 1);
                shapeFileFeatureLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

                Proj4Projection proj4 = new Proj4Projection();
                proj4.InternalProjectionParametersString = Proj4Projection.GetEpsgParametersString(4326);
                proj4.ExternalProjectionParametersString = Proj4Projection.GetGoogleMapParametersString();
                shapeFileFeatureLayer.FeatureSource.Projection = proj4;

                LayerOverlay shapeOverlay = new LayerOverlay("shapeOverlay", false, TileType.SingleTile);
                shapeOverlay.TransitionEffect = TransitionEffect.None;
               
                shapeOverlay.Layers.Add("ShapeLayer", shapeFileFeatureLayer);
                shapeOverlay.Layers.Add(googleLayer);
                System.Diagnostics.Debug.WriteLine("Page loading");
                Map1.CustomOverlays.Add(google);
                Map1.CustomOverlays.Add(shapeOverlay);
            }
        }

        protected void Button1Click(object sender, EventArgs e)
        {
            RectangleShape currentExtent = Map1.CurrentExtent;
            GoogleMapsLayer googleLayer = new GoogleMapsLayer("c:\\cache\\", "GoogleMapLayer", "ABQIAAAA1KPQi4YfHGdBrxrD7xfk3BShg55qzDjUncDQtZWMkgWc-6jGwhTE2_EhbB-MTW6vtSxa--SpoABjPA");
            ShapeFileFeatureLayer shapeLayer = (ShapeFileFeatureLayer)((LayerOverlay)Map1.CustomOverlays[1]).Layers["ShapeLayer"];

            shapeLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.FromArgb(100, 212, 220, 184), GeoColor.FromArgb(255, 132, 132, 154), 1);
            shapeLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;


            PdfDocument doc = new PdfDocument();
            PdfPage page = doc.AddPage();
            page.Size = PageSize.A4;

            GoogleMapPdfGeoCanvas canvas = new GoogleMapPdfGeoCanvas();

            double resolution = Math.Max(Map1.CurrentExtent.Width / Map1.Width.Value, Map1.CurrentExtent.Height / Map1.Height.Value);
            RectangleShape newDrawingExtent = new RectangleShape(Map1.CurrentExtent.UpperLeftPoint.X, Map1.CurrentExtent.UpperLeftPoint.Y, Map1.CurrentExtent.UpperLeftPoint.X + Map1.Width.Value * resolution, Map1.CurrentExtent.UpperLeftPoint.Y - Map1.Height.Value * resolution);

            canvas.DrawingArea = new System.Drawing.Rectangle(0, 0, 800, 600);

            canvas.BeginDrawing(page, Map1.CurrentExtent, GeographyUnit.Meter);

            System.Diagnostics.Debug.WriteLine("GoogleLayer begin drawing");
            googleLayer.Open();
            googleLayer.Draw(canvas, new Collection<SimpleCandidate>());
            googleLayer.Close();
            System.Diagnostics.Debug.WriteLine("GoogleLayer end drawing");

            System.Diagnostics.Debug.WriteLine("ShapeLayer begin drawing");
            shapeLayer.Open();
            shapeLayer.Draw(canvas, new Collection<SimpleCandidate>());
            shapeLayer.Close();
            System.Diagnostics.Debug.WriteLine("ShapeLayer end drawing \r\r");

            canvas.EndDrawing();

            doc.Save("c:\\test1.pdf");
            Process.Start("c:\\test1.pdf");

        }
    }
}
